@@ -1,8 +1,9 @@
 //! This module contains all the implemented exchanges.
 
 pub use openlimits_binance as binance;
-pub mod coinbase;
-pub mod nash;
+pub use openlimits_coinbase as coinbase;
+pub use openlimits_nash as nash;
+
 pub use openlimits_exchange::traits;
 pub use openlimits_exchange::shared;
 pub use openlimits_exchange::model;
