@@ -1,12 +1,12 @@
 use std::sync::mpsc::sync_channel;
 
 use openlimits::model::websocket::Subscription;
-use openlimits::exchange::traits::stream::ExchangeWs;
+use openlimits::exchange::traits::stream::ExchangeStream;
 use openlimits_exchange::model::market_pair::MarketPair;
 use openlimits::model::currency::Currency;
 use std::time::Duration;
 
-async fn test_subscription_callback(websocket: &impl ExchangeWs, sub: Subscription) {
+async fn test_subscription_callback(websocket: &impl ExchangeStream, sub: Subscription) {
     let (tx, rx) = sync_channel(0);
 
     websocket
@@ -20,13 +20,13 @@ async fn test_subscription_callback(websocket: &impl ExchangeWs, sub: Subscripti
     rx.recv_timeout(Duration::new(3, 0)).ok();
 }
 
-pub async fn orderbook(ws: &impl ExchangeWs) {
+pub async fn orderbook(ws: &impl ExchangeStream) {
     let market = MarketPair(Currency::ETH, Currency::BTC);
     let sub = Subscription::OrderBookUpdates(market);
     test_subscription_callback(ws, sub).await;
 }
 
-pub async fn trades(ws: &impl ExchangeWs) {
+pub async fn trades(ws: &impl ExchangeStream) {
     let market = MarketPair(Currency::ETH, Currency::BTC);
     let sub = Subscription::Trades(market);
     test_subscription_callback(ws, sub).await;
